@@ -31,32 +31,38 @@
 #include "capplet-util.h"
 
 static AppearanceData *
-init_appearance_data (int *argc, char ***argv)
+init_appearance_data (int *argc, char ***argv, GOptionContext *context)
 {
   AppearanceData *data = NULL;
-  gchar *gladefile;
-  GladeXML *ui;
-
-  bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
-  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-  textdomain (GETTEXT_PACKAGE);
+  gchar *uifile;
+  GtkBuilder *ui;
+  GError *err = NULL;
 
   g_thread_init (NULL);
   theme_thumbnail_factory_init (*argc, *argv);
-  gtk_init (argc, argv);
+  capplet_init (context, argc, argv);
   activate_settings_daemon ();
 
   /* set up the data */
-  gladefile = g_build_filename (GNOMECC_GLADE_DIR, "appearance.glade", NULL);
-  ui = glade_xml_new (gladefile, NULL, NULL);
-  g_free (gladefile);
+  uifile = g_build_filename (GNOMECC_GTKBUILDER_DIR, "appearance.ui",
+                             NULL);
+  ui = gtk_builder_new ();
+  gtk_builder_add_from_file (ui, uifile, &err);
+  g_free (uifile);
 
-  if (ui) {
-    data = g_new (AppearanceData, 1);
-    data->client = gconf_client_get_default ();
-    data->xml = ui;
-    data->thumb_factory = gnome_desktop_thumbnail_factory_new (GNOME_DESKTOP_THUMBNAIL_SIZE_NORMAL);
-  }
+  if (err)
+    {
+      g_warning (_("Could not load user interface file: %s"), err->message);
+      g_error_free (err);
+      g_object_unref (ui);
+    }
+  else
+    {
+      data = g_new (AppearanceData, 1);
+      data->client = gconf_client_get_default ();
+      data->ui = ui;
+      data->thumb_factory = gnome_desktop_thumbnail_factory_new (GNOME_DESKTOP_THUMBNAIL_SIZE_NORMAL);
+    }
 
   return data;
 }
@@ -78,32 +84,32 @@ main_window_response (GtkWidget *widget,
 
     g_object_unref (data->thumb_factory);
     g_object_unref (data->client);
-    g_object_unref (data->xml);
+    g_object_unref (data->ui);
   }
   else if (response_id == GTK_RESPONSE_HELP)
   {
       GtkNotebook *nb;
       gint pindex;
 
-      nb = GTK_NOTEBOOK (glade_xml_get_widget (data->xml, "main_notebook"));
+      nb = GTK_NOTEBOOK (appearance_capplet_get_widget (data, "main_notebook"));
       pindex = gtk_notebook_get_current_page (nb);
 
       switch (pindex)
       {
         case 0: /* theme */
-          capplet_help (GTK_WINDOW (widget), "goscustdesk-12"); 
+          capplet_help (GTK_WINDOW (widget), "goscustdesk-12");
           break;
         case 1: /* background */
-          capplet_help (GTK_WINDOW (widget), "goscustdesk-7"); 
+          capplet_help (GTK_WINDOW (widget), "goscustdesk-7");
           break;
         case 2: /* fonts */
-          capplet_help (GTK_WINDOW (widget), "goscustdesk-38"); 
+          capplet_help (GTK_WINDOW (widget), "goscustdesk-38");
           break;
         case 3: /* interface */
-          capplet_help (GTK_WINDOW (widget), "goscustuserinter-2"); 
+          capplet_help (GTK_WINDOW (widget), "goscustuserinter-2");
           break;
         default:
-          capplet_help (GTK_WINDOW (widget), "prefs-look-and-feel"); 
+          capplet_help (GTK_WINDOW (widget), "prefs-look-and-feel");
           break;
        }
   }
@@ -145,15 +151,13 @@ main (int argc, char **argv)
       { NULL }
     };
 
-  /* init */
-  data = init_appearance_data (&argc, &argv);
-  if (!data)
-    return 1;
-
   option_context = g_option_context_new (NULL);
   g_option_context_add_main_entries (option_context, option_entries, GETTEXT_PACKAGE);
 
-  capplet_init (option_context, &argc, &argv);
+  /* init */
+  data = init_appearance_data (&argc, &argv, option_context);
+  if (!data)
+    return 1;
 
   if (install_filename != NULL) {
     GFile *inst = g_file_new_for_commandline_arg (install_filename);
@@ -171,7 +175,7 @@ main (int argc, char **argv)
   ui_init (data);
 
   /* prepare the main window */
-  w = glade_xml_get_widget (data->xml, "appearance_window");
+  w = appearance_capplet_get_widget (data, "appearance_window");
   capplet_set_icon (w, "preferences-desktop-theme");
   gtk_widget_show_all (w);
 
@@ -188,12 +192,12 @@ main (int argc, char **argv)
     page_name = g_strconcat (start_page, "_vbox", NULL);
     g_free (start_page);
 
-    w = glade_xml_get_widget (data->xml, page_name);
+    w = appearance_capplet_get_widget (data, page_name);
     if (w != NULL) {
       GtkNotebook *nb;
       gint pindex;
 
-      nb = GTK_NOTEBOOK (glade_xml_get_widget (data->xml, "main_notebook"));
+      nb = GTK_NOTEBOOK (appearance_capplet_get_widget (data, "main_notebook"));
       pindex = gtk_notebook_page_num (nb, w);
       if (pindex != -1)
         gtk_notebook_set_current_page (nb, pindex);
@@ -201,6 +205,8 @@ main (int argc, char **argv)
     g_free (page_name);
   }
 
+  g_option_context_free (option_context);
+
   /* start the mainloop */
   gtk_main ();
 
