@@ -378,6 +378,12 @@ rebuild_rotation_combo (App *app)
 	combo_select (app->rotation_combo, _("Normal"));
 }
 
+static char *
+make_rate_string (int hz)
+{
+    return g_strdup_printf (_("%d Hz"), hz);
+}
+
 static void
 rebuild_rate_combo (App *app)
 {
@@ -412,7 +418,7 @@ rebuild_rate_combo (App *app)
 	    height == app->current_output->height)
 	{
 	    add_key (app->refresh_combo,
-		     idle_free (g_strdup_printf (_("%d Hz"), rate)),
+		     idle_free (make_rate_string (rate)),
 		     0, 0, rate, -1);
 
 	    if (rate > best)
@@ -420,8 +426,8 @@ rebuild_rate_combo (App *app)
 	}
     }
 
-    if (!combo_select (app->refresh_combo, idle_free (g_strdup_printf (_("%d Hz"), app->current_output->rate))))
-	combo_select (app->refresh_combo, idle_free (g_strdup_printf (_("%d Hz"), best)));
+    if (!combo_select (app->refresh_combo, idle_free (make_rate_string (app->current_output->rate))))
+	combo_select (app->refresh_combo, idle_free (make_rate_string (best)));
 }
 
 static int
@@ -540,12 +546,17 @@ rebuild_on_off_radios (App *app)
     g_signal_handlers_unblock_by_func (app->monitor_off_radio, G_CALLBACK (monitor_on_off_toggled_cb), app);
 }
 
+static char *
+make_resolution_string (int width, int height)
+{
+    return g_strdup_printf (_("%d x %d"), width, height);
+}
+
 static void
 rebuild_resolution_combo (App *app)
 {
     int i;
     GnomeRRMode **modes;
-    int best_w, best_h;
     const char *current;
 
     clear_combo (app->resolution_combo);
@@ -559,11 +570,10 @@ rebuild_resolution_combo (App *app)
     }
 
     g_assert (app->current_output != NULL);
+    g_assert (app->current_output->width != 0 && app->current_output->height != 0);
 
     gtk_widget_set_sensitive (app->resolution_combo, TRUE);
 
-    best_w = 0;
-    best_h = 0;
     for (i = 0; modes[i] != NULL; ++i)
     {
 	int width, height;
@@ -572,26 +582,14 @@ rebuild_resolution_combo (App *app)
 	height = gnome_rr_mode_get_height (modes[i]);
 
 	add_key (app->resolution_combo,
-		 idle_free (g_strdup_printf (_("%d x %d"), width, height)),
+		 idle_free (make_resolution_string (width, height)),
 		 width, height, 0, -1);
-
-	if (width * height > best_w * best_h)
-	{
-	    best_w = width;
-	    best_h = height;
-	}
     }
 
-    current = idle_free (g_strdup_printf (_("%d x %d"),
-					  app->current_output->width,
-					  app->current_output->height));
+    current = idle_free (make_resolution_string (app->current_output->width, app->current_output->height));
 
     if (!combo_select (app->resolution_combo, current))
-    {
-	combo_select (app->resolution_combo,
-		      idle_free (
-			  g_strdup_printf (_("%d x %d"), best_w, best_h)));
-    }
+	g_assert_not_reached ();
 }
 
 static void
@@ -696,6 +694,52 @@ on_rate_changed (GtkComboBox *box, gpointer data)
     foo_scroll_area_invalidate (FOO_SCROLL_AREA (app->area));
 }
 
+static void
+find_best_mode (GnomeRRMode **modes, int *out_width, int *out_height)
+{
+    int i;
+
+    *out_width = 0;
+    *out_height = 0;
+
+    for (i = 0; modes[i] != NULL; i++)
+    {
+	int w, h;
+
+	w = gnome_rr_mode_get_width (modes[i]);
+	h = gnome_rr_mode_get_height (modes[i]);
+
+	if (w * h > *out_width * *out_height)
+	{
+	    *out_width = w;
+	    *out_height = h;
+	}
+    }
+}
+
+static void
+select_resolution_for_current_output (App *app)
+{
+    GnomeRRMode **modes;
+    int width, height;
+
+    if (app->current_output->pref_width != 0 && app->current_output->pref_height != 0)
+    {
+	app->current_output->width = app->current_output->pref_width;
+	app->current_output->height = app->current_output->pref_height;
+	return;
+    }
+
+    modes = get_current_modes (app);
+    if (!modes)
+	return;
+
+    find_best_mode (modes, &width, &height);
+
+    app->current_output->width = width;
+    app->current_output->height = height;
+}
+
 static void
 monitor_on_off_toggled_cb (GtkToggleButton *toggle, gpointer data)
 {
@@ -720,6 +764,9 @@ monitor_on_off_toggled_cb (GtkToggleButton *toggle, gpointer data)
 
     app->current_output->on = is_on;
 
+    if (is_on)
+	select_resolution_for_current_output (app); /* The refresh rate will be picked in rebuild_rate_combo() */
+
     rebuild_gui (app);
     foo_scroll_area_invalidate (FOO_SCROLL_AREA (app->area));
 }
@@ -739,6 +786,9 @@ realign_outputs_after_resolution_change (App *app, GnomeOutputInfo *output_that_
 
     g_assert (app->current_configuration != NULL);
 
+    if (output_that_changed->width == old_width && output_that_changed->height == old_height)
+	return;
+
     old_right_edge = output_that_changed->x + old_width;
     old_bottom_edge = output_that_changed->y + old_height;
 
