@@ -27,8 +27,6 @@
 
 #include <string.h>
 
-#include <glade/glade.h>
-
 #include <libgnomekbd/gkbd-keyboard-drawing.h>
 #include <libgnomekbd/gkbd-util.h>
 
@@ -40,7 +38,8 @@
 #define DEFAULT_VARIANT_ID "__default__"
 
 enum {
-	COMBO_BOX_MODEL_COL_DESCRIPTION,
+	COMBO_BOX_MODEL_COL_SORT,
+	COMBO_BOX_MODEL_COL_VISIBLE,
 	COMBO_BOX_MODEL_COL_XKB_ID,
 	COMBO_BOX_MODEL_COL_REAL_ID
 };
@@ -54,24 +53,44 @@ typedef struct {
 } AddVariantData;
 
 static void
- xkb_layout_chooser_available_layouts_fill (GladeXML * chooser_dialog,
-					    const gchar cblid[],
-					    const gchar cbvid[],
-					    LayoutIterFunc layout_iterator,
-					    ConfigItemProcessFunc
-					    layout_handler,
-					    GCallback
-					    combo_changed_notify);
+
+
+
+
+
+
+
+xkb_layout_chooser_available_layouts_fill (GtkBuilder * chooser_dialog,
+					   const gchar cblid[],
+					   const gchar cbvid[],
+					   LayoutIterFunc layout_iterator,
+					   ConfigItemProcessFunc
+					   layout_handler,
+					   GCallback combo_changed_notify);
 
 static void
- xkb_layout_chooser_available_language_variants_fill (GladeXML *
-						      chooser_dialog);
 
-static void
- xkb_layout_chooser_available_country_variants_fill (GladeXML *
+
+
+
+
+
+
+xkb_layout_chooser_available_language_variants_fill (GtkBuilder *
 						     chooser_dialog);
 
 static void
+
+
+
+
+
+
+
+xkb_layout_chooser_available_country_variants_fill (GtkBuilder *
+						    chooser_dialog);
+
+static void
  xkb_layout_chooser_add_variant_to_available_country_variants
     (XklConfigRegistry * config_registry,
      XklConfigItem * parent_config_item, XklConfigItem * config_item,
@@ -85,15 +104,31 @@ static void
 	const gchar *xkb_id =
 	    config_item ?
 	    gkbd_keyboard_config_merge_items (parent_config_item->name,
-					      config_item->
-					      name) : parent_config_item->
-	    name;
+					      config_item->name) :
+	    parent_config_item->name;
 
-	gtk_list_store_insert_with_values (data->list_store, &iter, -1,
-					   COMBO_BOX_MODEL_COL_DESCRIPTION,
-					   utf_variant_name,
-					   COMBO_BOX_MODEL_COL_XKB_ID,
-					   xkb_id, -1);
+	if (config_item && g_object_get_data
+	    (G_OBJECT (config_item), XCI_PROP_EXTRA_ITEM)) {
+		gchar *buf =
+		    g_strdup_printf ("<i>%s</i>", utf_variant_name);
+		gtk_list_store_insert_with_values (data->list_store, &iter,
+						   -1,
+						   COMBO_BOX_MODEL_COL_SORT,
+						   utf_variant_name,
+						   COMBO_BOX_MODEL_COL_VISIBLE,
+						   buf,
+						   COMBO_BOX_MODEL_COL_XKB_ID,
+						   xkb_id, -1);
+		g_free (buf);
+	} else
+		gtk_list_store_insert_with_values (data->list_store, &iter,
+						   -1,
+						   COMBO_BOX_MODEL_COL_SORT,
+						   utf_variant_name,
+						   COMBO_BOX_MODEL_COL_VISIBLE,
+						   utf_variant_name,
+						   COMBO_BOX_MODEL_COL_XKB_ID,
+						   xkb_id, -1);
 	g_free (utf_variant_name);
 }
 
@@ -115,7 +150,9 @@ xkb_layout_chooser_add_language_to_available_languages (XklConfigRegistry *
 							list_store)
 {
 	gtk_list_store_insert_with_values (list_store, NULL, -1,
-					   COMBO_BOX_MODEL_COL_DESCRIPTION,
+					   COMBO_BOX_MODEL_COL_SORT,
+					   config_item->description,
+					   COMBO_BOX_MODEL_COL_VISIBLE,
 					   config_item->description,
 					   COMBO_BOX_MODEL_COL_REAL_ID,
 					   config_item->name, -1);
@@ -130,14 +167,16 @@ xkb_layout_chooser_add_country_to_available_countries (XklConfigRegistry *
 						       list_store)
 {
 	gtk_list_store_insert_with_values (list_store, NULL, -1,
-					   COMBO_BOX_MODEL_COL_DESCRIPTION,
+					   COMBO_BOX_MODEL_COL_SORT,
+					   config_item->description,
+					   COMBO_BOX_MODEL_COL_VISIBLE,
 					   config_item->description,
 					   COMBO_BOX_MODEL_COL_REAL_ID,
 					   config_item->name, -1);
 }
 
 static void
-xkb_layout_chooser_enable_disable_buttons (GladeXML * chooser_dialog)
+xkb_layout_chooser_enable_disable_buttons (GtkBuilder * chooser_dialog)
 {
 	GtkWidget *cbv =
 	    CWID (gtk_notebook_get_current_page
@@ -157,14 +196,14 @@ xkb_layout_chooser_enable_disable_buttons (GladeXML * chooser_dialog)
 }
 
 static void
-xkb_layout_chooser_available_variant_changed (GladeXML * chooser_dialog)
+xkb_layout_chooser_available_variant_changed (GtkBuilder * chooser_dialog)
 {
 	xkb_layout_preview_update (chooser_dialog);
 	xkb_layout_chooser_enable_disable_buttons (chooser_dialog);
 }
 
 static void
-xkb_layout_chooser_available_language_changed (GladeXML * chooser_dialog)
+xkb_layout_chooser_available_language_changed (GtkBuilder * chooser_dialog)
 {
 	xkb_layout_chooser_available_language_variants_fill
 	    (chooser_dialog);
@@ -172,7 +211,7 @@ xkb_layout_chooser_available_language_changed (GladeXML * chooser_dialog)
 }
 
 static void
-xkb_layout_chooser_available_country_changed (GladeXML * chooser_dialog)
+xkb_layout_chooser_available_country_changed (GtkBuilder * chooser_dialog)
 {
 	xkb_layout_chooser_available_country_variants_fill
 	    (chooser_dialog);
@@ -181,13 +220,13 @@ xkb_layout_chooser_available_country_changed (GladeXML * chooser_dialog)
 
 static void
 xkb_layout_chooser_page_changed (GtkWidget * notebook, GtkWidget * page,
-				 gint page_num, GladeXML * chooser_dialog)
+				 gint page_num, GtkBuilder * chooser_dialog)
 {
 	xkb_layout_chooser_available_variant_changed (chooser_dialog);
 }
 
 static void
-xkb_layout_chooser_available_language_variants_fill (GladeXML *
+xkb_layout_chooser_available_language_variants_fill (GtkBuilder *
 						     chooser_dialog)
 {
 	GtkWidget *cbl = CWID ("xkb_languages_available");
@@ -196,7 +235,8 @@ xkb_layout_chooser_available_language_variants_fill (GladeXML *
 	GtkTreeIter liter;
 
 	list_store = gtk_list_store_new
-	    (3, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
+	    (4, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
+	     G_TYPE_STRING);
 
 	if (gtk_combo_box_get_active_iter (GTK_COMBO_BOX (cbl), &liter)) {
 		GtkTreeModel *lm =
@@ -220,7 +260,7 @@ xkb_layout_chooser_available_language_variants_fill (GladeXML *
 	/* Turn on sorting after filling the store, since that's faster */
 	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE
 					      (list_store),
-					      COMBO_BOX_MODEL_COL_DESCRIPTION,
+					      COMBO_BOX_MODEL_COL_SORT,
 					      GTK_SORT_ASCENDING);
 
 	gtk_combo_box_set_model (GTK_COMBO_BOX (cbv),
@@ -229,7 +269,7 @@ xkb_layout_chooser_available_language_variants_fill (GladeXML *
 }
 
 static void
-xkb_layout_chooser_available_country_variants_fill (GladeXML *
+xkb_layout_chooser_available_country_variants_fill (GtkBuilder *
 						    chooser_dialog)
 {
 	GtkWidget *cbl = CWID ("xkb_countries_available");
@@ -238,7 +278,8 @@ xkb_layout_chooser_available_country_variants_fill (GladeXML *
 	GtkTreeIter liter;
 
 	list_store = gtk_list_store_new
-	    (3, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
+	    (4, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
+	     G_TYPE_STRING);
 
 	if (gtk_combo_box_get_active_iter (GTK_COMBO_BOX (cbl), &liter)) {
 		GtkTreeModel *lm =
@@ -261,7 +302,7 @@ xkb_layout_chooser_available_country_variants_fill (GladeXML *
 	/* Turn on sorting after filling the store, since that's faster */
 	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE
 					      (list_store),
-					      COMBO_BOX_MODEL_COL_DESCRIPTION,
+					      COMBO_BOX_MODEL_COL_SORT,
 					      GTK_SORT_ASCENDING);
 
 	gtk_combo_box_set_model (GTK_COMBO_BOX (cbv),
@@ -270,7 +311,7 @@ xkb_layout_chooser_available_country_variants_fill (GladeXML *
 }
 
 static void
-xkb_layout_chooser_available_layouts_fill (GladeXML *
+xkb_layout_chooser_available_layouts_fill (GtkBuilder *
 					   chooser_dialog,
 					   const gchar cblid[],
 					   const gchar cbvid[],
@@ -282,9 +323,11 @@ xkb_layout_chooser_available_layouts_fill (GladeXML *
 	GtkWidget *cbl = CWID (cblid);
 	GtkWidget *cbev = CWID (cbvid);
 	GtkCellRenderer *renderer;
-	GtkListStore *list_store =
-	    gtk_list_store_new (3, G_TYPE_STRING, G_TYPE_STRING,
-				G_TYPE_STRING);
+	GtkListStore *list_store;
+
+	list_store = gtk_list_store_new
+	    (4, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
+	     G_TYPE_STRING);
 
 	gtk_combo_box_set_model (GTK_COMBO_BOX (cbl),
 				 GTK_TREE_MODEL (list_store));
@@ -293,15 +336,14 @@ xkb_layout_chooser_available_layouts_fill (GladeXML *
 	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (cbl), renderer, TRUE);
 	gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (cbl),
 					renderer, "markup",
-					COMBO_BOX_MODEL_COL_DESCRIPTION,
-					NULL);
+					COMBO_BOX_MODEL_COL_VISIBLE, NULL);
 
 	layout_iterator (config_registry, layout_handler, list_store);
 
 	/* Turn on sorting after filling the model since that's faster */
 	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE
 					      (list_store),
-					      COMBO_BOX_MODEL_COL_DESCRIPTION,
+					      COMBO_BOX_MODEL_COL_SORT,
 					      GTK_SORT_ASCENDING);
 
 	g_signal_connect_swapped (G_OBJECT (cbl), "changed",
@@ -313,8 +355,7 @@ xkb_layout_chooser_available_layouts_fill (GladeXML *
 				    renderer, TRUE);
 	gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (cbev),
 					renderer, "markup",
-					COMBO_BOX_MODEL_COL_DESCRIPTION,
-					NULL);
+					COMBO_BOX_MODEL_COL_VISIBLE, NULL);
 
 	g_signal_connect_swapped (G_OBJECT (cbev), "changed",
 				  G_CALLBACK
@@ -367,7 +408,7 @@ xkl_layout_chooser_add_default_switcher_if_necessary (GSList *
 }
 
 static void
-xkb_layout_chooser_print (GladeXML * chooser_dialog)
+xkb_layout_chooser_print (GtkBuilder * chooser_dialog)
 {
 	GtkWidget *chooser = CWID ("xkb_layout_chooser");
 	GtkWidget *kbdraw =
@@ -385,7 +426,7 @@ xkb_layout_chooser_print (GladeXML * chooser_dialog)
 
 static void
 xkb_layout_chooser_response (GtkDialog * dialog,
-			     gint response, GladeXML * chooser_dialog)
+			     gint response, GtkBuilder * chooser_dialog)
 {
 	GdkRectangle rect;
 
@@ -422,12 +463,14 @@ xkb_layout_chooser_response (GtkDialog * dialog,
 }
 
 void
-xkb_layout_choose (GladeXML * dialog)
+xkb_layout_choose (GtkBuilder * dialog)
 {
-	GladeXML *chooser_dialog =
-	    glade_xml_new (GNOMECC_GLADE_DIR
-			   "/gnome-keyboard-properties.glade",
-			   "xkb_layout_chooser", NULL);
+	GtkBuilder *chooser_dialog;
+    
+    chooser_dialog = gtk_builder_new ();
+    gtk_builder_add_from_file (chooser_dialog, GNOMECC_UI_DIR
+                               "/gnome-keyboard-properties-layout-chooser.ui",
+                               NULL);
 	GtkWidget *chooser = CWID ("xkb_layout_chooser");
 	GtkWidget *lang_chooser = CWID ("xkb_languages_available");
 	GtkWidget *notebook = CWID ("choosers_nb");
@@ -460,12 +503,17 @@ xkb_layout_choose (GladeXML * dialog)
 				(xkb_layout_chooser_page_changed),
 				chooser_dialog);
 
-       gtk_combo_box_set_active (CWID ("xkb_countries_available"), 0);
+	gtk_combo_box_set_active (GTK_COMBO_BOX
+				  (CWID ("xkb_countries_available")),
+				  FALSE);
 
 	if (gtk_tree_model_iter_n_children
 	    (gtk_combo_box_get_model (GTK_COMBO_BOX (lang_chooser)),
 	     NULL)) {
-               gtk_combo_box_set_active (CWID ("xkb_languages_available"), 0);
+		gtk_combo_box_set_active (GTK_COMBO_BOX
+					  (CWID
+					   ("xkb_languages_available")),
+					  FALSE);
 	} else {
 		/* If language info is not available - remove the corresponding tab,
 		   pretend there is no notebook at all */
@@ -512,13 +560,13 @@ xkb_layout_choose (GladeXML * dialog)
 		}
 	}
 
-        xkb_layout_preview_update (chooser_dialog);
+	xkb_layout_preview_update (chooser_dialog);
 	gtk_dialog_run (GTK_DIALOG (chooser));
 	gtk_widget_destroy (chooser);
 }
 
 gchar *
-xkb_layout_chooser_get_selected_id (GladeXML * chooser_dialog)
+xkb_layout_chooser_get_selected_id (GtkBuilder * chooser_dialog)
 {
 	GtkWidget *cbv =
 	    CWID (gtk_notebook_get_current_page
