@@ -16,7 +16,7 @@
  */
 
 #include <gtk/gtk.h>
-#include <glade/glade.h>
+#include <glib/gi18n.h>
 
 #include "capplet-util.h"
 #include "gconf-property-editor.h"
@@ -35,7 +35,7 @@ enum {
 };
 
 static void
-update_mode_sensitivity (GladeXML *dialog, gint mode)
+update_mode_sensitivity (GtkBuilder *dialog, gint mode)
 {
 	gtk_widget_set_sensitive (WID ("box_ctw"), !mode);
 	gtk_widget_set_sensitive (WID ("box_gesture"), mode);
@@ -118,14 +118,14 @@ populate_gesture_combo (GtkWidget *combo)
 }
 
 static void
-delay_enable_toggled_cb (GtkWidget *checkbox, GladeXML *dialog)
+delay_enable_toggled_cb (GtkWidget *checkbox, GtkBuilder *dialog)
 {
 	gtk_widget_set_sensitive (WID ("delay_box"),
 				  gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (checkbox)));
 }
 
 static void
-dwell_enable_toggled_cb (GtkWidget *checkbox, GladeXML *dialog)
+dwell_enable_toggled_cb (GtkWidget *checkbox, GtkBuilder *dialog)
 {
 	gtk_widget_set_sensitive (WID ("dwell_box"),
 				  gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (checkbox)));
@@ -170,7 +170,7 @@ gconf_value_changed (GConfClient *client,
 }
 
 void
-setup_accessibility (GladeXML *dialog, GConfClient *client)
+setup_accessibility (GtkBuilder *dialog, GConfClient *client)
 {
 	gconf_client_add_dir (client, MT_GCONF_HOME,
 			      GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
