@@ -19,10 +19,10 @@
  */
 
 #include "document-tile.h"
+#include "config.h"
 
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <string.h>
-#include <libgnomeui/gnome-icon-lookup.h>
 #include <gio/gio.h>
 
 #include "slab-gnome-util.h"
@@ -166,7 +166,8 @@ document_tile_new (const gchar *in_uri, const gchar *mime_type, time_t modified)
 
 	this = g_object_new (DOCUMENT_TILE_TYPE, "tile-uri", uri, "nameplate-image", image,
 		"nameplate-header", header, "nameplate-subheader", subheader, 
-		"nameplate-tooltip", tooltip_text, "context-menu", context_menu, NULL);
+		"context-menu", context_menu, NULL);
+	gtk_widget_set_tooltip_text (GTK_WIDGET (this), tooltip_text);
 
 	g_free (uri);
 	if (tooltip_text)
@@ -318,11 +319,14 @@ document_tile_private_setup (DocumentTile *this)
 	GAppInfo *app;
 
 	GConfClient *client;
+	GError *error = NULL;
 
 	file = g_file_new_for_uri (TILE (this)->uri);
-	app = g_file_query_default_handler (file, NULL, NULL);
+	app = g_file_query_default_handler (file, NULL, &error);
 	priv->default_app = app;
 
+	if (error)
+		g_error_free (error);
 	g_object_unref (file);
 
 	priv->delete_enabled =
@@ -378,7 +382,8 @@ document_tile_finalize (GObject *g_object)
 	g_free (priv->mime_type);
 	g_free (priv->force_icon_name);
 
-	g_object_unref (priv->default_app);
+	if (priv->default_app)
+		g_object_unref (priv->default_app);
 
 	if (priv->notify_signal_id)
 		g_signal_handler_disconnect (priv->agent, priv->notify_signal_id);
@@ -408,7 +413,8 @@ load_image (DocumentTile *tile)
 
 	gchar *icon_id = NULL;
 	gboolean free_icon_id = TRUE;
-	GnomeThumbnailFactory *thumbnail_factory;
+	GnomeDesktopThumbnailFactory *thumbnail_factory;
+	GIcon *icon;
 
 	libslab_checkpoint ("document-tile.c: load_image(): start for %s", TILE (tile)->uri);
 
@@ -424,12 +430,14 @@ load_image (DocumentTile *tile)
 
 	thumbnail_factory = libslab_thumbnail_factory_get ();
 
-	icon_id = gnome_thumbnail_factory_lookup (thumbnail_factory, TILE (tile)->uri, priv->modified);
+	icon_id = gnome_desktop_thumbnail_factory_lookup (thumbnail_factory, TILE (tile)->uri, priv->modified);
 
-	if (! icon_id)
-		icon_id = gnome_icon_lookup (
-			gtk_icon_theme_get_default (), thumbnail_factory,
-			TILE (tile)->uri, NULL, NULL, priv->mime_type, 0, NULL);
+	if (! icon_id) {
+		icon = g_content_type_get_icon (priv->mime_type);
+		g_object_get (icon, "name", &icon_id, NULL);
+
+		g_object_unref (icon);
+	}	
 
 exit:
 
@@ -1017,8 +1025,10 @@ user_docs_trigger (Tile *tile, TileEvent *event, TileAction *action)
 		item->uri       = tile->uri;
 		item->mime_type = priv->mime_type;
 		item->mtime     = priv->modified;
-		item->app_name  = (gchar *) g_app_info_get_name (priv->default_app);
-		item->app_exec  = (gchar *) g_app_info_get_executable (priv->default_app);
+		if (priv->default_app) {
+			item->app_name  = (gchar *) g_app_info_get_name (priv->default_app);
+			item->app_exec  = (gchar *) g_app_info_get_executable (priv->default_app);
+		}
 
 		bookmark_agent_add_item (priv->agent, item);
 		g_free (item);
